@@ -83,8 +83,12 @@ def ls(target):
         blobs = BlobStorageClient().list_blobs(container_name, blob_prefix)
 
         for blob in blobs:
-            click.echo('{:>25} {:>5} {}'.format(
-                str(blob['last_modified'] or ''), blob['size'] or '', blob['name']))
+            if blob['type'] == 'prefix':
+                click.echo('{:>31} {}'.format('PRE', blob['name']))
+            elif blob['type'] == 'blob':
+                click.echo('{:>25} {:>5} {}'.format(
+                    str(blob['last_modified']), blob['size'], blob['name']))
+
     else:
         containers = BlobStorageClient().list_contaners()
 
@@ -121,6 +125,10 @@ def cp(src, dst):
         container_to_local(src, dst, delete_flag=False)
     elif dst.startswith('blob://'):
         local_to_container(src, dst, delete_flag=False)
+    else:
+        msg = 'rm: Invalid source or target: {} to {}'.format(
+            original_src, original_dst)
+        raise Exception(msg)
 
     click.echo('copy: {} to {}'.format(original_src, original_dst))
 
@@ -137,6 +145,10 @@ def mv(src, dst):
         container_to_local(src, dst, delete_flag=True)
     elif dst.startswith('blob://'):
         local_to_container(src, dst, delete_flag=True)
+    else:
+        msg = 'rm: Invalid source or target: {} to {}'.format(
+            original_src, original_dst)
+        raise Exception(msg)
 
     click.echo('move: {} to {}'.format(original_src, original_dst))
 
